@@ -20,15 +20,19 @@
 - (void)removeItemWithPath:(NSArray *)pathArray;
 - (Directory *)addNewDirectory:(NSArray *)pathArray;
 - (Directory *)addItem:(MyItem *)file toDir:(NSArray *)pathArray;
+- (Directory *)addItem:(MyItem *)file;
 - (void)print:(NSString *)prefix;
 - (unsigned int)itemCount;
 - (id)itemAtIndex:(unsigned int)index;
 - (id)itemWithPath:(NSArray *)pathArray;
 - (BOOL)containsItemWithName:(NSString *)itemName;
 - (MyItem *)itemWithDescription:(NSString *)desc;
-- (NSMutableArray *)recursiveMembers;
 - (void)removeItem:(MyItem *)item;
 - (NSEnumerator *)objectEnumerator;
 - (Directory *)copy;
+- (Directory *)subdirWithID:(unsigned)itemID;
+- (NSDictionary *)flatten;
++ (NSArray *)normalizePathArray:(NSArray *)pathArray;
++ (NSString *)stringFromPathArray:(NSArray *)pathArray;
 
 @end
