@@ -206,8 +206,10 @@
 {
 	if (![status isIdle])
 	{
-		int result = NSRunAlertPanel(@"Quit XNJB", @"There are still items in the queue.  Are you sure you want to quit?  This could crash your NJB and/or XNJB.",
-																 @"No", @"Yes", nil);
+		int result = NSRunAlertPanel(NSLocalizedString(@"Quit XNJB", nil),
+																 NSLocalizedString(@"There are still items in the queue.  Are you sure you want to quit?  This could crash your NJB and/or XNJB.", nil),
+																 NSLocalizedString(@"No", nil),
+																 NSLocalizedString(@"Yes", nil), nil);
 		if (result == NSAlertDefaultReturn)
 			return NO;
 	}
@@ -292,7 +294,7 @@
 	NJBQueueItem *connect = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(connect)];
 	[connect setStatus:STATUS_CONNECTING];
 	
-	[queueTab addItem:connect withSubItems:nil withDescription:@"Connecting to NJB"];
+	[queueTab addItem:connect withSubItems:nil withDescription:NSLocalizedString(@"Connecting to NJB", nil)];
 	
 	[[njbQueue lock] lock];
 	[[njbQueue queue] addObject:connect];
@@ -306,7 +308,7 @@
 {
 	NJBQueueItem *disconnect = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(disconnect)];
 	[disconnect setStatus:STATUS_DISCONNECTING];
-	[queueTab addItem:disconnect withSubItems:nil withDescription:@"Disconnecting from NJB"];
+	[queueTab addItem:disconnect withSubItems:nil withDescription:NSLocalizedString(@"Disconnecting from NJB", nil)];
 	
 	[[njbQueue lock] lock];
 	[[njbQueue queue] addObject:disconnect];
@@ -337,7 +339,10 @@
 	}
 	// ask if they really want to try to connect if appears already connected
 	// we don't get told when they pull the plug out so maybe we're not, let's ask...
-	int result = NSRunAlertPanel(@"Connect to NJB", @"It appears that we are already connected. Do you want to try to connect again?", @"No", @"Yes", nil);
+	int result = NSRunAlertPanel(NSLocalizedString(@"Connect to NJB", nil),
+															 NSLocalizedString(@"It appears that we are already connected. Do you want to try to connect again?", nil),
+															 NSLocalizedString(@"No", nil),
+															 NSLocalizedString(@"Yes", nil), nil);
 	if (result == NSAlertDefaultReturn)
 		return;
 	[self connectToNJB];
@@ -360,14 +365,14 @@
 */
 - (void)NJBDisconnected:(NSNotification *)note
 {
-	[connectButton setTitle:@"Connect"];
+	[connectButton setTitle:NSLocalizedString(@"Connect", nil)];
 }
 
 /* called when we connect
 */
 - (void)NJBConnected:(NSNotification *)note
 {
-	[connectButton setTitle:@"Disconnect"];
+	[connectButton setTitle:NSLocalizedString(@"Disconnect", nil)];
 }
 
 /* called when the main window is closing
