@@ -39,6 +39,8 @@
 	BOOL turbo;
 	BOOL mtpDevice;
 	LIBMTP_mtpdevice_t *device;
+	uint16_t *supportedFiletypes;
+	uint16_t supportedFiletypesLength;
 	
 	NSString *deviceString;
 	NSString *firmwareVersionString;
@@ -67,7 +69,6 @@
 - (NJBTransactionResult *)downloadFile:(DataFile *)dataFile;
 - (NJBTransactionResult *)uploadFile:(DataFile *)dataFile toFolder:(NSString *)path;
 - (NJBTransactionResult *)deleteFile:(MyItem *)file fromDir:(Directory *)parentDir;
-- (NJBTransactionResult *)deleteFile:(MyItem *)file;
 - (unsigned long long)totalDiskSpace;
 - (unsigned long long)freeDiskSpace;
 - (NSCalendarDate *)jukeboxTime;
@@ -97,8 +98,9 @@
 - (uint32_t)picturesAssoc;
 - (uint32_t)videoAssoc;
 - (uint32_t)zencastAssoc;
-- (BOOL)isAudioType:(LIBMTP_filetype_t) filetype;
+- (BOOL)isAudioType:(LIBMTP_filetype_t)filetype;
 - (BOOL)isMTPDevice;
+- (BOOL)isSupportedFileType:(LIBMTP_filetype_t)type;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
 int mtp_progress (uint64_t const sent, uint64_t const total, void const * const data);
