@@ -63,6 +63,8 @@ StatusDisplayer *statusDisplayerGlobal;
 		
 		downloadingTracks = NO;
 		downloadingFiles = NO;
+		
+		supportedFiletypes = NULL;
 	}
 	return self;
 }
@@ -78,6 +80,9 @@ StatusDisplayer *statusDisplayerGlobal;
 	[deviceIDString release];
 	[deviceVersionString release];
 	
+	if (supportedFiletypes != NULL)
+		free(supportedFiletypes);
+	
 	[super dealloc];
 }
 
@@ -318,7 +323,6 @@ StatusDisplayer *statusDisplayerGlobal;
 			firmwareVersionString = [versions objectAtIndex:0];
 		}
 		
-		// unneeded
 		uint8_t currentLevel = 0;
 		if (LIBMTP_Get_Batterylevel(device, &batteryLevelMax, &currentLevel) != 0)
 		{
@@ -326,6 +330,8 @@ StatusDisplayer *statusDisplayerGlobal;
 			return 0;
 		}
 		
+		LIBMTP_Get_Supported_Filetypes(device, &supportedFiletypes, &supportedFiletypesLength);
+		
 		// download the data files to the cache
 		//[self dataFiles];
 	}
@@ -485,19 +491,19 @@ StatusDisplayer *statusDisplayerGlobal;
 			if (frame != NULL)
 			{
 				if (frame->data.strval == NULL)
-					[track setCodec:CODEC_UNDEFINED];
+					[track setFileType:LIBMTP_FILETYPE_UNDEF_AUDIO];
 				else
 				{
 					if (strcmp(frame->data.strval, NJB_CODEC_MP3) == 0)
-						[track setCodec:CODEC_MP3];
+						[track setFileType:LIBMTP_FILETYPE_MP3];
 					else if (strcmp(frame->data.strval, NJB_CODEC_WMA) == 0)
-						[track setCodec:CODEC_WMA];
+						[track setFileType:LIBMTP_FILETYPE_WMA];
 					else if (strcmp(frame->data.strval, NJB_CODEC_WAV) == 0)
-						[track setCodec:CODEC_WAV];
+						[track setFileType:LIBMTP_FILETYPE_WAV];
 					else if (strcmp(frame->data.strval, NJB_CODEC_AA) == 0)
-						[track setCodec:CODEC_AA];
+						[track setFileType:LIBMTP_FILETYPE_AUDIBLE];
 					else
-						[track setCodec:CODEC_UNDEFINED];
+						[track setFileType:LIBMTP_FILETYPE_UNDEF_AUDIO];
 				}
 			}
 			
@@ -554,22 +560,7 @@ StatusDisplayer *statusDisplayerGlobal;
 			if (track->album != NULL)
 				[myTrack setAlbum:[NSString stringWithUTF8String:track->album]];
 			
-			switch (track->filetype)
-			{
-				case LIBMTP_FILETYPE_WAV:
-					[myTrack setCodec:CODEC_WAV];
-					break;
-				case LIBMTP_FILETYPE_MP3:
-					[myTrack setCodec:CODEC_MP3];
-					break;
-				case LIBMTP_FILETYPE_WMA:
-					[myTrack setCodec:CODEC_WMA];
-					break;
-				default:
-					[myTrack setCodec:CODEC_UNDEFINED];
-					break;
-			}
-			
+			[myTrack setFileType:track->filetype];
 			[myTrack setFilesize:track->filesize];
 			if (track->filename != NULL)
 				[myTrack setFilename:[NSString stringWithUTF8String:track->filename]];
@@ -659,6 +650,16 @@ StatusDisplayer *statusDisplayerGlobal;
 	}
 	else
 	{
+		if (![self isSupportedFileType:[track fileType]])
+		{
+			return [[[NJBTransactionResult alloc] initWithSuccess:NO
+																							 resultString:NSLocalizedString(@"Your player does not support this file type: please convert to a different type", nil)] autorelease];
+		}
+		if (![self isAudioType:[track fileType]])
+		{
+			return [[[NJBTransactionResult alloc] initWithSuccess:NO
+																							 resultString:NSLocalizedString(@"You can't upload non-music files in the music tab - please use the data tab", nil)] autorelease];
+		}
 		LIBMTP_track_t *trackmeta = [self libmtpTrack_tFromTrack:track];
 		if (trackmeta->filename != NULL)
 			free(trackmeta->filename);
@@ -951,13 +952,14 @@ StatusDisplayer *statusDisplayerGlobal;
 		file = files;
 		while (file != NULL)
 		{
-			if (![self isAudioType:file->filetype])
-			{
+			//if (![self isAudioType:file->filetype])
+			//{
 				DataFile *dataFile = [[DataFile alloc] init];
 				if (file->filename != NULL)
 					[dataFile setFilename:[NSString stringWithUTF8String:file->filename]];
 				[dataFile setSize:file->filesize];
 				[dataFile setItemID:file->item_id];
+				[dataFile setFileType:file->filetype];
 				
 				Directory *dir = [dirDict objectForKey:[NSNumber numberWithUnsignedInt:file->parent_id]];
 				if (dir == nil)
@@ -965,7 +967,7 @@ StatusDisplayer *statusDisplayerGlobal;
 				[dir addItem:dataFile toDir:nil];
 				
 				[dataFile release];
-			}
+			//}
 			
 			tmp = file;
 			file = file->next;
@@ -1077,67 +1079,9 @@ StatusDisplayer *statusDisplayerGlobal;
 	}
 	else
 	{
-		uint16_t objectFormat = LIBMTP_FILETYPE_UNKNOWN;
+		uint16_t objectFormat = [dataFile fileType];
 		uint32_t parenthandle = [parentDir itemID];
 		
-		// todo: add more object formats
-		NSString *extension = [[[dataFile fullPath] pathExtension] lowercaseString];
-		if ([extension isEqualToString:@"wmv"])
-		{
-			objectFormat = LIBMTP_FILETYPE_WMV;
-			//	parenthandle = [self videoAssoc];
-		}
-		else if ([extension isEqualToString:@"avi"])
-		{
-			objectFormat = LIBMTP_FILETYPE_AVI;
-			//	parenthandle = [self videoAssoc];
-		}
-		else if ([extension isEqualToString:@"mpg"] || [extension isEqualToString:@"mpeg"])
-		{
-			objectFormat = LIBMTP_FILETYPE_MPEG;
-			//	parenthandle = [self videoAssoc];
-		}
-		else if ([extension isEqualToString:@"asf"])
-		{
-			objectFormat = LIBMTP_FILETYPE_ASF;
-			//	parenthandle = [self videoAssoc];
-		}
-		else if ([extension isEqualToString:@"qt"])
-		{
-			objectFormat = LIBMTP_FILETYPE_QT;
-			//	parenthandle = [self videoAssoc];
-		}
-		else if ([extension isEqualToString:@"jpg"] || [extension isEqualToString:@"jpeg"])
-		{
-			objectFormat = LIBMTP_FILETYPE_JPEG;
-			//	parenthandle = [self picturesAssoc];
-		}
-		else if ([extension isEqualToString:@"tif"] || [extension isEqualToString:@"tiff"])
-		{
-			objectFormat = LIBMTP_FILETYPE_TIFF;
-			//	parenthandle = [self picturesAssoc];
-		}
-		else if ([extension isEqualToString:@"bmp"])
-		{
-			objectFormat = LIBMTP_FILETYPE_BMP;
-			//	parenthandle = [self picturesAssoc];
-		}
-		else if ([extension isEqualToString:@"gif"])
-		{
-			objectFormat = LIBMTP_FILETYPE_GIF;
-			//	parenthandle = [self picturesAssoc];
-		}
-		else if ([extension isEqualToString:@"pict"])
-		{
-			objectFormat = LIBMTP_FILETYPE_PICT;
-			//	parenthandle = [self picturesAssoc];
-		}
-		else if ([extension isEqualToString:@"png"])
-		{
-			objectFormat = LIBMTP_FILETYPE_PNG;
-			//	parenthandle = [self picturesAssoc];
-		}
-		
 		LIBMTP_file_t *genfile = LIBMTP_new_file_t();
 		genfile->filesize = [dataFile size];
 		genfile->filetype = objectFormat;
@@ -1370,7 +1314,8 @@ StatusDisplayer *statusDisplayerGlobal;
 			Playlist *newPlaylist = [[Playlist alloc] init];
 			
 			[newPlaylist setPlaylistID:pl->playlist_id];
-			[newPlaylist setName:[NSString stringWithUTF8String:pl->name]];
+			if (pl->name != NULL)
+				[newPlaylist setName:[NSString stringWithUTF8String:pl->name]];
 			int i = 0;
 			for (i = 0; i < pl->no_tracks; i++)
 			{
@@ -1803,21 +1748,7 @@ int mtp_progress (uint64_t const sent, uint64_t const total, void const * const
 {
 	LIBMTP_track_t *libmtp_track = LIBMTP_new_track_t();
 	
-	switch ([track codec])
-	{
-		case CODEC_MP3:
-			libmtp_track->filetype = LIBMTP_FILETYPE_MP3;
-			break;
-		case CODEC_WAV:
-			libmtp_track->filetype = LIBMTP_FILETYPE_WAV;
-			break;
-		case CODEC_WMA:
-			libmtp_track->filetype = LIBMTP_FILETYPE_WMA;
-			break;
-		default:
-			libmtp_track->filetype = LIBMTP_FILETYPE_UNDEF_AUDIO;
-			break;
-	}
+	libmtp_track->filetype = [track fileType];
 		
 	// we need to have title, album and artist set else some players get confused
 	if ([[track title] length] == 0)
@@ -1869,4 +1800,18 @@ int mtp_progress (uint64_t const sent, uint64_t const total, void const * const
 	return mtpDevice;
 }
 
+- (BOOL)isSupportedFileType:(LIBMTP_filetype_t)type
+{
+	if (!mtpDevice)
+		return YES;
+	
+	int i = 0;
+	for (i = 0; i < supportedFiletypesLength; i++)
+	{
+		if (supportedFiletypes[i] == type)
+			return YES;
+	}
+	return NO;
+}
+
 @end
