@@ -72,6 +72,8 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   { "Creative Zen Vision:M", 0x041e, 0x413e, DEVICE_FLAG_NONE },
   // Reported by marazm@o2.pl
   { "Creative Zen V", 0x041e, 0x4150, DEVICE_FLAG_NONE },
+  // Reported by Darel on the XNJB forums
+  { "Creative Zen V plus", 0x041e, 0x4152, DEVICE_FLAG_NONE },
 
   /*
    * Samsung
@@ -152,6 +154,8 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
    */
   { "Toshiba Gigabeat MEGF-40", 0x0930, 0x0009, DEVICE_FLAG_NONE },
   { "Toshiba Gigabeat", 0x0930, 0x000c, DEVICE_FLAG_NONE },
+  // From libgphoto2
+  { "Toshiba Gigabeat S", 0x0930, 0x0010, DEVICE_FLAG_NONE },
   // Reported by Rob Brown
   { "Toshiba Gigabeat P10", 0x0930, 0x0011, DEVICE_FLAG_NONE },
 
@@ -159,7 +163,16 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
    * Archos
    */
   // Reported by gudul1@users.sourceforge.net
-  { "Archos 104 (MTP mode)", 0x0e79, 0x120a, DEVICE_FLAG_NONE }
+  { "Archos 104 (MTP mode)", 0x0e79, 0x120a, DEVICE_FLAG_NONE },
+
+  /*
+   * Dunlop (OEM of EGOMAN ltd?) reported by Nanomad
+   * This unit is falsely detected as USB mass storage in Linux
+   * so special care is needed to blacklist the device in kernel
+   * or similar to get it properly userspace:d.
+   */
+  { "Dunlop MP3 player 1GB / EGOMAN MD223AFD", 0x10d6, 0x2200, DEVICE_FLAG_UNLOAD_DRIVER}
+  
 };
 static const int mtp_device_table_size = sizeof(mtp_device_table) / sizeof(LIBMTP_device_entry_t);
 
@@ -511,6 +524,18 @@ static int init_ptp_usb (PTPParams* params, PTP_USB* ptp_usb, struct usb_device*
       return -1;
     }
     ptp_usb->handle = device_handle;
+#ifdef LIBUSB_HAS_DETACH_KERNEL_DRIVER_NP
+    /*
+     * If this device is known to be wrongfully claimed by other kernel
+     * drivers (such as mass storage), then try to unload it to make it
+     * accessible from user space.
+     */
+    if (ptp_usb->device_flags & DEVICE_FLAG_UNLOAD_DRIVER) {
+      if (usb_detach_kernel_driver_np(device_handle, dev->config->interface->altsetting->bInterfaceNumber)) {
+	perror("usb_detach_kernel_driver_np()");
+      }
+    }
+#endif
     if (usb_claim_interface(device_handle, dev->config->interface->altsetting->bInterfaceNumber)) {
       perror("usb_claim_interface()");
       return -1;
